@@ -4,7 +4,7 @@
    colSumsPrim
    colwiseProd
 
-   Sren Hjsgaard
+   Søren Højsgaard
 
 ** *************************************************************/
 
